summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEvgeny Grin (Karlson2k) <k2k@narod.ru>2016-08-23 20:13:14 +0000
committerEvgeny Grin (Karlson2k) <k2k@narod.ru>2016-08-23 20:13:14 +0000
commitdaeda7abc81cbec6cc00dab4db22db96308488d7 (patch)
tree15177ecc0bac27d94b84dc867ddd9860deb30c64
parent515c50a1fa2706b2d0cd9687c381662e39b30be8 (diff)
mhd_sockets.h: unify some macro names
-rw-r--r--src/microhttpd/connection.c16
-rw-r--r--src/microhttpd/daemon.c10
-rw-r--r--src/microhttpd/mhd_sockets.h12
3 files changed, 19 insertions, 19 deletions
diff --git a/src/microhttpd/connection.c b/src/microhttpd/connection.c
index 7c0ce674..bf3f4d00 100644
--- a/src/microhttpd/connection.c
+++ b/src/microhttpd/connection.c
@@ -146,9 +146,9 @@ socket_start_extra_buffering (struct MHD_Connection *connection)
{
int res = MHD_NO;
#if defined(TCP_CORK) || defined(TCP_NOPUSH)
- const _MHD_SOCKOPT_BOOL_TYPE on_val = 1;
+ const MHD_SCKT_OPT_BOOL_ on_val = 1;
#if defined(TCP_NODELAY)
- const _MHD_SOCKOPT_BOOL_TYPE off_val = 0;
+ const MHD_SCKT_OPT_BOOL_ off_val = 0;
#endif /* TCP_NODELAY */
if (!connection)
return MHD_NO;
@@ -191,9 +191,9 @@ socket_start_no_buffering_flush (struct MHD_Connection *connection)
{
#if defined(TCP_CORK) || defined(TCP_NOPUSH)
int res = MHD_YES;
- const _MHD_SOCKOPT_BOOL_TYPE off_val = 0;
+ const MHD_SCKT_OPT_BOOL_ off_val = 0;
#if defined(TCP_NODELAY)
- const _MHD_SOCKOPT_BOOL_TYPE on_val = 1;
+ const MHD_SCKT_OPT_BOOL_ on_val = 1;
#endif /* TCP_NODELAY */
#if !defined(TCP_CORK)
const int dummy = 0;
@@ -237,9 +237,9 @@ socket_start_no_buffering (struct MHD_Connection *connection)
{
#if defined(TCP_NODELAY)
int res = MHD_YES;
- const _MHD_SOCKOPT_BOOL_TYPE on_val = 1;
+ const MHD_SCKT_OPT_BOOL_ on_val = 1;
#if defined(TCP_CORK) || defined(TCP_NOPUSH)
- const _MHD_SOCKOPT_BOOL_TYPE off_val = 0;
+ const MHD_SCKT_OPT_BOOL_ off_val = 0;
#endif /* TCP_CORK || TCP_NOPUSH */
if (!connection)
return MHD_NO;
@@ -276,9 +276,9 @@ socket_start_normal_buffering (struct MHD_Connection *connection)
{
#if defined(TCP_NODELAY)
int res = MHD_YES;
- const _MHD_SOCKOPT_BOOL_TYPE off_val = 0;
+ const MHD_SCKT_OPT_BOOL_ off_val = 0;
#if defined(TCP_CORK)
- _MHD_SOCKOPT_BOOL_TYPE cork_val = 0;
+ MHD_SCKT_OPT_BOOL_ cork_val = 0;
socklen_t param_size = sizeof (cork_val);
#endif /* TCP_CORK */
if (!connection)
diff --git a/src/microhttpd/daemon.c b/src/microhttpd/daemon.c
index 68491938..076a7ada 100644
--- a/src/microhttpd/daemon.c
+++ b/src/microhttpd/daemon.c
@@ -1131,7 +1131,7 @@ recv_param_adapter (struct MHD_Connection *connection,
ret = (ssize_t) recv (connection->socket_fd,
other,
- (_MHD_socket_funcs_size) i,
+ (MHD_SCKT_SEND_SIZE_) i,
MSG_NOSIGNAL);
#if EPOLL_SUPPORT
if ( (0 > ret) && (MHD_SCKT_ERR_IS_EAGAIN_ (MHD_socket_get_error_ ())) )
@@ -1180,7 +1180,7 @@ send_param_adapter (struct MHD_Connection *connection,
if (0 != (connection->daemon->options & MHD_USE_SSL))
return (ssize_t) send (connection->socket_fd,
other,
- (_MHD_socket_funcs_size) i,
+ (MHD_SCKT_SEND_SIZE_) i,
MSG_NOSIGNAL);
#if LINUX
if ( (connection->write_buffer_append_offset ==
@@ -1232,7 +1232,7 @@ send_param_adapter (struct MHD_Connection *connection,
http://lists.gnu.org/archive/html/libmicrohttpd/2011-02/msg00015.html */
}
#endif
- ret = (ssize_t) send (connection->socket_fd, other, (_MHD_socket_funcs_size)i, MSG_NOSIGNAL);
+ ret = (ssize_t) send (connection->socket_fd, other, (MHD_SCKT_SEND_SIZE_)i, MSG_NOSIGNAL);
err = MHD_socket_get_error_();
#if EPOLL_SUPPORT
if ( (0 > ret) && (MHD_SCKT_ERR_IS_EAGAIN_(err)) )
@@ -3667,7 +3667,7 @@ MHD_start_daemon_va (unsigned int flags,
MHD_AccessHandlerCallback dh, void *dh_cls,
va_list ap)
{
- const _MHD_SOCKOPT_BOOL_TYPE on = 1;
+ const MHD_SCKT_OPT_BOOL_ on = 1;
struct MHD_Daemon *daemon;
MHD_socket socket_fd;
struct sockaddr_in servaddr4;
@@ -4056,7 +4056,7 @@ MHD_start_daemon_va (unsigned int flags,
(http://msdn.microsoft.com/en-us/library/ms738574%28v=VS.85%29.aspx);
and may also be missing on older POSIX systems; good luck if you have any of those,
your IPv6 socket may then also bind against IPv4 anyway... */
- const _MHD_SOCKOPT_BOOL_TYPE v6_only =
+ const MHD_SCKT_OPT_BOOL_ v6_only =
(MHD_USE_DUAL_STACK != (flags & MHD_USE_DUAL_STACK));
if (0 > setsockopt (socket_fd,
IPPROTO_IPV6, IPV6_V6ONLY,
diff --git a/src/microhttpd/mhd_sockets.h b/src/microhttpd/mhd_sockets.h
index b38a5d55..b01134a9 100644
--- a/src/microhttpd/mhd_sockets.h
+++ b/src/microhttpd/mhd_sockets.h
@@ -171,22 +171,22 @@
/**
* _MHD_SOCKOPT_BOOL_TYPE is type for bool parameters for setsockopt()/getsockopt()
*/
#ifdef MHD_POSIX_SOCKETS
- typedef int _MHD_SOCKOPT_BOOL_TYPE;
+ typedef int MHD_SCKT_OPT_BOOL_;
#else /* MHD_WINSOCK_SOCKETS */
- typedef BOOL _MHD_SOCKOPT_BOOL_TYPE;
+ typedef BOOL MHD_SCKT_OPT_BOOL_;
#endif /* MHD_WINSOCK_SOCKETS */
/**
* _MHD_socket_funcs_size is type used to specify size for send and recv
* functions
*/
#if !defined(MHD_WINSOCK_SOCKETS)
- typedef size_t _MHD_socket_funcs_size;
+ typedef size_t MHD_SCKT_SEND_SIZE_;
#else
- typedef int _MHD_socket_funcs_size;
+ typedef int MHD_SCKT_SEND_SIZE_;
#endif
/**
@@ -171,22 +171,22 @@
/**
- * _MHD_SOCKOPT_BOOL_TYPE is type for bool parameters for setsockopt()/getsockopt()
+ * MHD_SCKT_OPT_BOOL_ is type for bool parameters for setsockopt()/getsockopt()
*/
#ifdef MHD_POSIX_SOCKETS
@@ -171,22 +171,22 @@
#endif /* MHD_WINSOCK_SOCKETS */
/**
- * _MHD_socket_funcs_size is type used to specify size for send and recv
+ * MHD_SCKT_SEND_SIZE_ is type used to specify size for send and recv
* functions
*/